# Stanford Engineering CS193p: Developing iOS 11 Apps with Swift (Fall 2017)

![](art/iTunesU.jpg?raw=true)

This repo contains my lecture notes and projects from Paul Hegarty's classic [CS 193p iPhone Application Development course](http://web.stanford.edu/class/cs193p/cgi-bin/drupal/) offered by The School of Engineering at Stanford and is available on [iTunes-U](https://itunes.apple.com/us/course/developing-ios-11-apps-with-swift/id1309275316).

This course is described as being updated for iOS 11 and Swift 4, Tools, and APIs required to build applications for the iPhone and iPad platforms using the iOS SDK. The course covers user interface design for mobile devices and unique user interactions using multi-touch technologies. Object-oriented design using model-view-controller paradigm, memory management, the Swift programming language. Other topics include: animation, mobile device power management, multi-threading, networking and performance considerations.

## Apple Documents
[Apple Developer Documentation](https://developer.apple.com/documentation)

[SWIFT.ORG](https://swift.org)
- [Swift Programming Language](https://developer.apple.com/library/content/documentation/Swift/Conceptual/Swift_Programming_Language/index.html)
- [Swift API Guidelines](https://swift.org/documentation/api-design-guidelines)

## Other Tutorials
 [Lets Build That App](https://www.letsbuildthatapp.com) [![](art/play.png?raw=true)](https://www.youtube.com/channel/UCuP2vJ6kRutQBfRmdcI92mA)

 [Code With Chris](https://codewithchris.com) [![](art/play.png?raw=true)](https://www.youtube.com/channel/UC2D6eRvCeMtcF5OGHf1-trw)
 - [The 7 Day App Action Plan](https://codewithchris.com/actionplan)

 [Cornell](https://www.youtube.com/channel/UCUDPjOx1yPRGxsO6AFtBZSg) [![](art/play.png?raw=true)](https://youtu.be/wwjqigjVNaA)

 Brian Advent [![](art/play.png?raw=true)](https://www.youtube.com/channel/UCysEngjfeIYapEER9K8aikw)
 
 [Ray Wenderlich](https://www.raywenderlich.com/) [![](art/play.png?raw=true)](https://www.youtube.com/user/rwenderlich)

## Lectures
Lecture | Slides | Code | Video | Date
| ------------- | ------------- | ------------- | ------------- | ------------- |
| 1. | [Course Overview: Intro to iOS 11, Xcode 9, and Swift 4](https://drive.google.com/open?id=13hhB7smc4Z8JEOtzukHU9dV3u6z7jqr8) | [![](art/Xcode.png?raw=true)](./democode/Lecture_1_concentration) | [![](art/play.png?raw=true)](https://youtu.be/71pyOB4TPRE?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 2. | [MVC: Concentration Demo Continued](https://drive.google.com/open?id=16jrukJGDRR-Gve1A5dZMXaPM0UhlLB3Z) | [![](art/Xcode.png?raw=true)](./democode/Lecture_2_concentration) | [![](art/play.png?raw=true)](https://youtu.be/w7a79cx3UaY?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 3. | [Swift Programming Language](https://drive.google.com/open?id=1q9653aFt1nWU0DG1rzzmmcW0Yu1W28dQ) | [![](art/Xcode.png?raw=true)](./democode/Lecture_3_concentration) | [![](art/play.png?raw=true)](https://youtu.be/ZbpjTPzf8x4?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 4. | [More Swift](https://drive.google.com/open?id=1uip1sUSEIhw4xCjR6FC-C0lJpBVRNxGJ) | | [![](art/play.png?raw=true)](https://youtu.be/FU2V0YRQIOw?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 5. | [Drawing](https://drive.google.com/open?id=1Jn0swH3SsuF037FO5vMM1Ll08Q2GEBNE) | | [![](art/play.png?raw=true)](https://youtu.be/h2hm2AtanRU?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 6. | [Multitouch ](https://drive.google.com/open?id=1wkOS1q03LCvUwh5T0N0dg7EN3UryE0ZR) | | [![](art/play.png?raw=true)](https://youtu.be/_a0X5J3M2I8?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 7. | [Multiple MVCs, Timer and Animation](https://drive.google.com/open?id=1upQheYzftXhw4Dl93dH0Y1T0bUi-t7XG) | | [![](art/play.png?raw=true)](https://youtu.be/5B5IRK9wYjI?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 8. | [Animation](https://drive.google.com/open?id=1CzbESrN58ELXI9ET3w_y2DbmM4cwiC5S) | | [![](art/play.png?raw=true)](https://youtu.be/84ZhYhAwYqo?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 9. | [View Controller Lifecycle and Scroll View](https://drive.google.com/open?id=14l1O5jiwGxHAY3mO17okmZrKhHwWPy7G) | | [![](art/play.png?raw=true)](https://youtu.be/tLsPoVDXDG8?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 10. | [Multithreading and Autolayout](https://drive.google.com/open?id=1WIHYOTFsEjeuqTks80iY_AF3wQUR1Dhy) | | [![](art/play.png?raw=true)](https://youtu.be/kl2bDYiSgoc?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 11. | [Drag and Drop, Table View and Collection View](https://drive.google.com/open?id=1omjKZRXjZK8oAcR9M0gRkzn3sdq-NpY4) | | [![](art/play.png?raw=true)](https://youtu.be/M3X9o9wbn9o?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 12. | [Drag and Drop, Table View, Collection View, and Text Field](https://drive.google.com/open?id=1WDs_sd_cTyaNFnqGQ5J-15qPK62QDiy_) | | [![](art/play.png?raw=true)](https://youtu.be/cTUlAXBiTho?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 13. | [Persistence and Documents](https://drive.google.com/open?id=1QjbYAGXJRsWoYpLEt_qfN48DpVZOQkhS) | | [![](art/play.png?raw=true)](https://youtu.be/ckCjIJbxYLY?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 14. | [Persistence and Documents Demo](https://drive.google.com/open?id=1LjCJC8CjXn3zC_liNOeX7-IVzKq6-0jv) | | [![](art/play.png?raw=true)](https://youtu.be/gs3kj4XsqdY?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 15. | [Alerts, Notifications, Application Lifecycle](https://drive.google.com/open?id=1ciUtI2LjFDCZ0_WozB2mqZaXbACf5BBj) | | [![](art/play.png?raw=true)](https://youtu.be/K1tmZhuuyt0?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 16. | [More Segues](https://drive.google.com/open?id=1fKBUpdlplIg2YhWyxwhZuEEAUMP0Bq-6) | | [![](art/play.png?raw=true)](https://youtu.be/ke9fzOdg5Pk?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017
| 17. | [Core Motion and Camera](https://drive.google.com/open?id=1cnXorvzbZTWQi0NqthDGqtx0y1c54p4X) | | [![](art/play.png?raw=true)](https://youtu.be/qOTY7cEl9ZA?list=PLPA-ayBrweUzGFmkT_W65z64MoGnKRZMq) | Fall 2017

## Friday Sessions
Sessions | Lecture | Video | Date
| ------------- | ------------- | ------------- | -------------
| 1. | Debugging and Xcode Tips and Tricks | [![](art/play.png?raw=true)](https://youtu.be/-UtIg4Lt7T8) | Fall 2017
| 2. | Github and Source Control Workflow | [![](art/play.png?raw=true)](https://youtu.be/LvhXql24EOs) | Fall 2017
| 3. | Instruments | [![](art/play.png?raw=true)](https://youtu.be/s_SOYcYBnGU) | Fall 2017

## Reading Assignments

Reading  | Name
| ------------- | -------------
| 1. | [Reading 1: Intro to Swift](https://drive.google.com/open?id=1hDA3IPWAUwrWqx-RD_QU_oyCPVWlDdnD)
| 2. | [Reading 2: Intro to Swift](https://drive.google.com/open?id=1QTJisCkQuGJCO3-2jH0KWQXnSY8Gnpf1)
| 3. | [Reading 3: Finishing off Swift](https://drive.google.com/open?id=1VVOsiK2IgRGqKJZnIvFNtUb4Dwq6NCDJ)

## Assignments
PS  | Name | Code
| ------------- | ------------- | -------------
| 1. | [Assignment 1: Concentration](https://drive.google.com/open?id=1u-b4agSQqKBROU5dTKryHz6nwdqDWS8G) |
| 2. | [Assignment 2: Set](https://drive.google.com/open?id=14bpF6U5yyGDFNXIiRtZRHJjxAJPyxFYT) |
| 3. | [Assignment 3: Graphical Set](https://drive.google.com/open?id=1ILaX7nRZ80mke8-TStMo7HnnJGPxZhPE) |
| 4. | [Assignment 4: Animated Set](https://drive.google.com/open?id=1XGeM7HnWYcnvSCcB5akpz6SQZXGE3zst) |
| 5. | [Assignment 5: Image Gallery](https://drive.google.com/open?id=1l4TGfyKwhD3oxUOGxHql-9UCafE6nxXk) |
| 6. | [Assignment 6: Persistent Image Gallery](https://drive.google.com/open?id=1gJaKfTrHZsrh1sezkzUav8KxvkJCxJGp) |

## Licensing
My CS193p projects are licensed under [the MIT License](LICENSE).
